from distutils.core import setup

setup(
	name='pybsorts',
	version='0.2',
	description='Basic sorting algorithmes for arrays',
	author='Samy Melaine',
	author_email='melaine.samy@gmail.com',
	url='https://github.com/SamyMe/pybsorts/',
	download_url='https://github.com/SamyMe/pybsorts/tarball/0.2',
	keywords=['sort','array','basic','bubble','merge','quick','insertion','heap','semectop'],
	classifiers=[ 
		'License :: OSI Approved :: MIT License',
		'Programming Language :: Python',
	],
)
